==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/General/scrobbler/translations/scrobbler_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_CN">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="30"/>
        <source>Scrobbler Plugin</source>
        <translation>Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="49"/>
        <source>About Scrobbler Plugin</source>
        <translation>关于 Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="50"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Qmmp Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Scrobbler 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>User name:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="65"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.1.orig.tar.gz: qmmp-0.4.1/src/plugins/General/scrobbler/translations/scrobbler_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="30"/>
        <source>Scrobbler Plugin</source>
        <translation>Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="50"/>
        <source>About Scrobbler Plugin</source>
        <translation>关于 Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Qmmp Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Scrobbler 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>User name:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
</context>
</TS>
